# eric7.Plugins.VcsPlugins.vcsMercurial.GpgExtension.gpg

Module implementing the gpg extension interface.

### Global Attributes

None

### Classes

Gpg | Class implementing the gpg extension interface.

### Functions

None

## Gpg

Class implementing the gpg extension interface.

### Derived from

HgExtension

### Class Attributes

None

### Class Methods

None

### Methods

Gpg | Constructor
hgGpgSign | Public method used to list the available bookmarks.
hgGpgSignatures | Public method used to list all signed changesets.
hgGpgVerifySignatures | Public method used to verify the signatures of a revision.
shutdown | Public method used to shutdown the gpg interface.

### Static Methods

None

#### Gpg (Constructor)

Gpg(vcs)

Constructor

vcs (Hg)
  reference to the Mercurial vcs object

#### Gpg.hgGpgSign

hgGpgSign(revisions=None)

Public method used to list the available bookmarks.

revisions (list of str)
  list containing the revisions to be signed

#### Gpg.hgGpgSignatures

hgGpgSignatures()

Public method used to list all signed changesets.

#### Gpg.hgGpgVerifySignatures

hgGpgVerifySignatures(rev=None)

Public method used to verify the signatures of a revision.

rev (str)
  revision to check

#### Gpg.shutdown

shutdown()

Public method used to shutdown the gpg interface.

Up